CLI Reference
=============

.. currentmodule:: pyjess

This section documents the command line interface (CLI) of PyJess.

Usage
-----

.. argparse::
    :module: pyjess.cli
    :func: argument_parser
    :prog: pyjess
    :nodescription:
